pub enum TxStatus {
Active,
Closed(Arc<str>),
}Expand description
The possible states of a Tx.
Variants
Implementations
Sourceimpl TxStatus
impl TxStatus
Sourcepub fn as_closed_mut(&mut self) -> Option<&mut Arc<str>>
pub fn as_closed_mut(&mut self) -> Option<&mut Arc<str>>
Optionally returns mutable references to the inner fields if this is a TxStatus::Closed, otherwise None
Sourcepub fn as_closed(&self) -> Option<&Arc<str>>
pub fn as_closed(&self) -> Option<&Arc<str>>
Optionally returns references to the inner fields if this is a TxStatus::Closed, otherwise None
Sourcepub fn into_closed(self) -> Result<Arc<str>, Self>
pub fn into_closed(self) -> Result<Arc<str>, Self>
Returns the inner fields if this is a TxStatus::Closed, otherwise returns back the enum in the Err case of the result